@@ -22,7 +22,7 @@ import tempfile
 from concurrent.futures import ProcessPoolExecutor, as_completed
 from functools import partial
 from pathlib import Path
-from typing import List
+from typing import List, Optional
 
 import click
 from click import echo
@@ -184,21 +184,40 @@ def build_quantity_tense(size: int) -> str:
     is_flag=True,
     help="Check formatting on the file(s).",
 )
+@click.option(
+    "--indent",
+    type=int,
+    help="Indent spacing. ex: 3",
+)
 @click.option(
     "--quiet",
     is_flag=True,
     help="Do not print diff when reformatting.",
 )
+@click.option(
+    "--profile",
+    type=str,
+    help="Enable defaults by template language. ops: django, jinja, nunjucks, handlebars",
+)
 def main(
     src: List[str],
     extension: str,
     ignore: str,
     reformat: bool,
+    indent: Optional[int],
     check: bool,
     quiet: bool,
+    profile: str,
 ) -> None:
     """djLint · lint and reformat HTML templates."""
-    config = Config(src[0], extension=extension, ignore=ignore, quiet=quiet)
+    config = Config(
+        src[0],
+        extension=extension,
+        ignore=ignore,
+        indent=indent,
+        quiet=quiet,
+        profile=profile,
+    )
 
     temp_file = None
 
