@@ -16,6 +16,7 @@ def indent_html(rawcode: str, config: Config) -> str:
 
     beautified_code = ""
     indent_level = 0
+    is_raw_first_line = False
     is_block_raw = False
 
     slt_html = config.break_html_tags
@@ -27,6 +28,12 @@ def indent_html(rawcode: str, config: Config) -> str:
     slt_template = config.single_line_template_tags
 
     for item in rawcode_flat_list:
+        # if a raw tag first line
+        if not is_block_raw and re.search(
+            config.ignored_group_opening, item, re.IGNORECASE | re.VERBOSE
+        ):
+            is_raw_first_line = True
+
         # if a raw tag then start ignoring
         if re.search(config.ignored_group_opening, item, re.IGNORECASE | re.VERBOSE):
             is_block_raw = True
@@ -97,6 +104,9 @@ def indent_html(rawcode: str, config: Config) -> str:
             tmp = (indent * indent_level) + item + "\n"
             indent_level = indent_level + 1
 
+        elif is_raw_first_line is True:
+            tmp = (indent * indent_level) + item + "\n"
+
         elif is_block_raw is True:
             tmp = item + "\n"
 
@@ -108,13 +118,14 @@ def indent_html(rawcode: str, config: Config) -> str:
         else:
             tmp = (indent * indent_level) + item + "\n"
 
-        # we can try to fix template tags
-        tmp = re.sub(r"({[{|%]\-?)(\w[^}].+?)([}|%]})", r"\1 \2\3", tmp)
-        tmp = re.sub(r"({[{|%])([^}].+?[^(?:\ |\-)])([}|%]})", r"\1\2 \3", tmp)
-        tmp = re.sub(r"({[{|%])([^}].+?[^ ])(\-[}|%]})", r"\1\2 \3", tmp)
-
-        # handlebars templates
-        tmp = re.sub(r"({{#(?:each|if).+?[^ ])(}})", r"\1 \2", tmp)
+        # we can try to fix template tags. ignore handlebars
+        if config.profile != "handlebars":
+            tmp = re.sub(r"({[{|%]\-?)(\w[^}].+?)([}|%]})", r"\1 \2\3", tmp)
+            tmp = re.sub(r"({[{|%])([^}].+?[^(?:\ |\-)])([}|%]})", r"\1\2 \3", tmp)
+            tmp = re.sub(r"({[{|%])([^}].+?[^ ])(\-[}|%]})", r"\1\2 \3", tmp)
+        else:
+            # handlebars templates
+            tmp = re.sub(r"({{#(?:each|if).+?[^ ])(}})", r"\1 \2", tmp)
 
         # if a opening raw tag then start ignoring.. only if there is no closing tag
         # on the same line
@@ -122,6 +133,7 @@ def indent_html(rawcode: str, config: Config) -> str:
             re.search(config.ignored_group_opening, item, re.IGNORECASE | re.VERBOSE)
         ) or re.search(config.ignored_block_opening, item, re.IGNORECASE | re.VERBOSE):
             is_block_raw = True
+            is_raw_first_line = False
 
         # if a normal tag, we can try to expand attributes
         elif (
@@ -158,4 +170,14 @@ def indent_html(rawcode: str, config: Config) -> str:
 
         beautified_code = beautified_code + tmp
 
+    # should we add blank lines after load tags?
+    if config.blank_line_after_tag:
+        for tag in [x.strip() for x in config.blank_line_after_tag.split(",")]:
+            beautified_code = re.sub(
+                fr"((?:{{%\s*?{tag}[^}}]+?%}}\n?)+)",
+                r"\1\n",
+                beautified_code,
+                re.IGNORECASE,
+            )
+
     return beautified_code.strip() + "\n"
