@@ -8,7 +8,7 @@ import re
 
 ## get pyproject.toml settings
 from pathlib import Path
-from typing import Dict, Optional, Union
+from typing import Dict, List, Optional, Union
 
 import tomlkit
 
@@ -59,21 +59,40 @@ class Config:
         src: str,
         ignore: Optional[str] = None,
         extension: Optional[str] = None,
+        indent: Optional[int] = None,
         quiet: Optional[bool] = False,
+        profile: Optional[str] = None,
     ):
 
         djlint_settings = load_pyproject_settings(Path(src))
 
         # custom configuration options
         self.extension: str = str(extension or djlint_settings.get("extension", "html"))
-        self.ignore: str = str(ignore or djlint_settings.get("ignore", ""))
         self.quiet: str = str(quiet or djlint_settings.get("quiet", ""))
         self.custom_blocks: str = str(
             build_custom_blocks(djlint_settings.get("custom_blocks")) or ""
         )
 
+        # ignore is based on input and also profile
+        self.ignore: str = str(ignore or djlint_settings.get("ignore", ""))
+
+        # codes to exclude
+        profile_dict: Dict[str, List[str]] = {
+            "django": ["J", "N", "M"],
+            "jinja": ["D", "N", "M"],
+            "nunjucks": ["D", "J", "M"],
+            "handlebars": ["D", "J", "N"],
+        }
+
+        self.profile_code: List[str] = profile_dict.get(
+            str(profile or djlint_settings.get("profile", "all")).lower(), []
+        )
+        self.profile: str = str(
+            profile or djlint_settings.get("profile", "all")
+        ).lower()
+
         # base options
-        self.indent: str = djlint_settings.get("indent", "    ")
+        self.indent: str = (indent or int(djlint_settings.get("indent", 4))) * " "
 
         default_exclude: str = r"""
             \.venv
@@ -102,6 +121,11 @@ class Config:
                 re.escape(x.strip()) for x in extend_exclude.split(",")
             )
 
+        # add blank line after load tags
+        self.blank_line_after_tag: Optional[str] = djlint_settings.get(
+            "blank_line_after_tag", None
+        )
+
         # contents of tags will not be formatted, but tags will be formatted
         self.ignored_block_opening: str = r"""
               <style
@@ -203,7 +227,6 @@ class Config:
                     | path
                     | script
                     | style
-                    | source
                     | details
                     | summary
                 )
@@ -263,7 +286,6 @@ class Config:
                     | path
                     | script
                     | style
-                    | source
                     | details
                     | summary
                 )
@@ -378,13 +400,13 @@ class Config:
         """
         )
 
-        self.ignored_blocks: list = [
-            r"<(script|style|pre|textarea).*?(?:%s).*?</(\1)>",
-            r"<!--.*?(?:%s).*?-->",
-            r"{\*.*?(?:%s).*?\*}",
-            r"{\#.*?(?:%s).*?\#}",
-            r"<\?php.*?(?:%s).*?\?>",
-        ]
+        self.ignored_blocks: str = r"""
+              <(script|style|pre|textarea).*?</(\1)>
+            | <!--.*?-->
+            | {\*.*?\*}
+            | {\#.*?\#}
+            | <\?php.*?\?>
+        """
 
         self.ignored_inline_blocks: str = r"""
               <!--.*?-->
@@ -421,6 +443,7 @@ class Config:
               link
             | img
             | meta
+            | source
         """
 
         self.single_line_template_tags: str = r"""
